@@ -17,8 +17,20 @@
 # limitations under the License.
 #
 #
-from .core import Client, Project, Pipeline, Result, Terminology, DocumentCollection, Pear, Process, \
-    EvaluationConfiguration, ResourceContainer
+from .core import (
+    Client,
+    Project,
+    Pipeline,
+    Result,
+    Terminology,
+    DocumentCollection,
+    Pear,
+    Process,
+    EvaluationConfiguration,
+    ResourceContainer,
+    ExtendedRequestException,
+    TextanalysisMode
+)
 
 __all__ = [
     "Client",
@@ -30,5 +42,7 @@ __all__ = [
     "DocumentCollection",
     "Pear",
     "Process",
-    "ResourceContainer"
+    "ResourceContainer",
+    "ExtendedRequestException",
+    "TextanalysisMode"
 ]
