@@ -44,6 +44,22 @@ def test_delete(process, requests_mock):
 
     process.delete()
 
+def test_process_unprocessed_not_supported(process, requests_mock):
+    with pytest.raises(OperationNotSupported):
+        process.process_unprocessed()
+
+def test_process_unprocessed(client_version_8, requests_mock):
+    project = client_version_8.get_project(PROJECT_NAME)
+    process = Process(project, "my_process", "my_doc_source", "my_pipeline")
+    requests_mock.post(
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{PROJECT_NAME}/"
+        f"documentSources/{process.document_source_name}/processes/{process.name}/reprocessUnprocessed",
+        headers={"Content-Type": "application/json"},
+        json={"payload": None, "errorMessages": []}
+    )
+    
+    process.process_unprocessed()
+
 
 def test_rerun(process, requests_mock):
     requests_mock.post(
@@ -55,6 +71,32 @@ def test_rerun(process, requests_mock):
 
     process.rerun()
 
+def test_rerun_document_names_not_supported(process):
+    with pytest.raises(OperationNotSupported):
+        process.rerun(document_names=["doc1.txt", "doc2.txt"])
+
+
+def test_rerun_document_names(client_version_8, requests_mock):
+    project = client_version_8.get_project(PROJECT_NAME)
+    process = Process(project, "my_process", "my_doc_source", "my_pipeline")
+    
+    expected_document_names = ["doc1.txt", "doc2.txt"]
+
+    captured_document_names = []
+    def callback(request, _content):
+        captured_document_names.extend(request.json()["documentNames"])
+        return {"payload": None, "errorMessages": []}
+    
+    requests_mock.post(
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{PROJECT_NAME}/"
+        f"documentSources/{process.document_source_name}/processes/{process.name}/reprocess",
+        headers={"Content-Type": "application/json"},
+        json=callback,
+    )
+
+    process.rerun(document_names=expected_document_names)
+    assert captured_document_names == expected_document_names
+
 
 def test_create_and_run_process(process, requests_mock):
     process_name = "process-on-process"
@@ -202,7 +244,7 @@ def test_export_text_analysis_export_v6(client_version_6, requests_mock):
                                 "coveredText": "Hello World",
                                 "id": 66753,
                             }
-                        ]
+                        ],
                         # truncated #
                     }
                     # truncated #
@@ -272,6 +314,77 @@ def test_export_text_analysis_with_page_and_pagsize(client_version_6, requests_m
     assert len(export3["textAnalysisResultDtos"]) == 100
     assert export3["textAnalysisResultDtos"][-1]["documentName"] == "Document (200).txt"
 
+def test_export_text_analysis_document_selection(client_version_8, requests_mock):
+    project = Project(client_version_8, PROJECT_NAME)
+    collection = project.get_document_collection(COLLECTION_NAME)
+    process_name = "my-process"
+
+    requests_mock.get(
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/"
+        f"documentSources/{collection.name}/processes/{process_name}",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "processName": process_name,
+                "pipelineName": "my-pipeline",
+                "documentSourceName": collection.name,
+                "state": "IDLE",
+                # Truncated
+            },
+            "errorMessages": [],
+        },
+    )
+    process = collection.get_process(process_name)
+    actual_document_names = []
+    def callback(request, _content):
+        actual_document_names.extend(request.json()["documentNames"])
+        return {
+            "payload": {
+                "textAnalysisResultDtos": [
+                    {"documentName": name, "annotationDtos": []} for name in actual_document_names
+                ],
+                "projectName": project.name,
+                # Truncated
+            },
+            "errorMessages": [],
+        }
+
+    requests_mock.post(
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/"
+        f"documentCollections/{process.document_source_name}/processes/{process.name}/export",
+        headers={"Content-Type": "application/json"},
+        json=callback,
+    )
+    expected_document_names = ["text1.txt", "text2.txt"]
+    export = process.export_text_analysis(document_names=expected_document_names)
+    textanalysis_results = export["textAnalysisResultDtos"]
+    assert len(textanalysis_results) == len(expected_document_names)
+    assert all(result["documentName"] in expected_document_names for result in textanalysis_results)
+
+def test_export_text_analysis_document_selection_not_supported(client_version_7, requests_mock):
+    project = Project(client_version_7, PROJECT_NAME)
+    collection = project.get_document_collection(COLLECTION_NAME)
+    process_name = "my-process"
+    requests_mock.get(
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/"
+        f"documentSources/{collection.name}/processes/{process_name}",
+        headers={"Content-Type": "application/json"},
+        json={
+            "payload": {
+                "processName": process_name,
+                "pipelineName": "my-pipeline",
+                "documentSourceName": collection.name,
+                "state": "IDLE",
+                # Truncated
+            },
+            "errorMessages": [],
+        },
+    )
+    process = collection.get_process(process_name)
+
+    with pytest.raises(OperationNotSupported):
+        process.export_text_analysis(document_names=["text1.txt", "text2.txt"])
+
 
 def test_export_text_analysis_to_cas_v5(client_version_5):
     document_name = "document0001.txt"
@@ -286,7 +399,9 @@ def test_export_text_analysis_to_cas_v5(client_version_5):
         process.export_text_analysis_to_cas(document_name)
 
 
-def test_export_text_analysis_to_cas_v6_full_name_support(client_version_6_17_platform_6_50, requests_mock):
+def test_export_text_analysis_to_cas_v6_full_name_support(
+    client_version_6_17_platform_6_50, requests_mock
+):
     project = client_version_6_17_platform_6_50.get_project(PROJECT_NAME)
     collection = project.get_document_collection(COLLECTION_NAME)
     document_name = "document.txt"
@@ -324,7 +439,9 @@ def test_export_text_analysis_to_cas_v6_full_name_support(client_version_6_17_pl
     assert cas.sofa_string == "Test"
 
 
-def test_export_text_analysis_to_cas_v6_onlycas_export_by_name_support(client_version_6_7, requests_mock):
+def test_export_text_analysis_to_cas_v6_onlycas_export_by_name_support(
+    client_version_6_7, requests_mock
+):
     project = client_version_6_7.get_project(PROJECT_NAME)
     collection = project.get_document_collection(COLLECTION_NAME)
     document_id = "document0001"
@@ -348,7 +465,7 @@ def test_export_text_analysis_to_cas_v6_onlycas_export_by_name_support(client_ve
         f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/documentCollections/{collection.name}"
         f"/documents/{document_id}/processes/{process.name}/exportTextAnalysisResultTypeSystem",
         headers={"Content-Type": "application/xml"},
-        text=empty_typesystem
+        text=empty_typesystem,
     )
 
     requests_mock.get(
@@ -363,7 +480,7 @@ def test_export_text_analysis_to_cas_v6_onlycas_export_by_name_support(client_ve
         f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/documentCollections/{collection.name}"
         f"/processes/{process.name}/textAnalysisResult",
         headers={"Content-Type": "application/vnd.uima.cas+xmi"},
-        text=expected_xmi
+        text=expected_xmi,
     )
 
     cas = process.export_text_analysis_to_cas(document_name)
@@ -396,14 +513,14 @@ def test_export_text_analysis_to_cas_v6_only_id_support(client_version_6, reques
         f"/processes/{process.name}/textAnalysisResultTypeSystem",
         headers={"Content-Type": "application/xml"},
         text=empty_typesystem,
-        status_code=405
+        status_code=405,
     )
 
     requests_mock.get(
         f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/documentCollections/{collection.name}"
         f"/documents/{document_id}/processes/{process.name}/exportTextAnalysisResultTypeSystem",
         headers={"Content-Type": "application/xml"},
-        text=empty_typesystem
+        text=empty_typesystem,
     )
 
     requests_mock.get(
@@ -420,7 +537,7 @@ def test_export_text_analysis_to_cas_v6_only_id_support(client_version_6, reques
         f"/processes/{process.name}/textAnalysisResult",
         headers={"Content-Type": "application/vnd.uima.cas+xmi"},
         text=expected_xmi,
-        status_code=405
+        status_code=405,
     )
 
     requests_mock.get(
@@ -478,8 +595,8 @@ def test_export_text_analysis_to_cas_v6_7_provide_typesystem(client_version_6_7,
 
 
 def test_export_text_analysis_to_cas_annotation_types_not_supported(
-        client_version_6_17_0_platform_6_48_0,
-        requests_mock):
+    client_version_6_17_0_platform_6_48_0, requests_mock
+):
     project = client_version_6_17_0_platform_6_48_0.get_project(PROJECT_NAME)
     collection = project.get_document_collection(COLLECTION_NAME)
     document_id = "document0001"
@@ -519,7 +636,8 @@ def test_export_text_analysis_to_cas_annotation_types_not_supported(
     cas = process.export_text_analysis_to_cas(
         document_name,
         type_system=cas_typesystem,
-        annotation_types="de.averbis.types.health.Diagnosis")
+        annotation_types="de.averbis.types.health.Diagnosis",
+    )
 
     assert cas.sofa_string == "Test"
 
@@ -608,26 +726,29 @@ def test_evaluate(client_version_6, requests_mock):
     requests_mock.post(
         f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/documentCollections/{collection.name}/evaluationProcesses",
         headers={"Content-Type": "application/json"},
-        json={"payload": None, "errorMessages": []}
+        json={"payload": None, "errorMessages": []},
     )
-    list_processes_payload = [{
-        "processName": evaluation_process_name,
-        "documentSourceName": collection.name
-    }]
+    list_processes_payload = [
+        {"processName": evaluation_process_name, "documentSourceName": collection.name}
+    ]
     requests_mock.get(
         f"{API_EXPERIMENTAL}/textanalysis/projects/{project.name}/processes",
         json={"payload": list_processes_payload, "errorMessages": []},
     )
 
-    clinical_section_keyword_config = EvaluationConfiguration("de.averbis.types.health.ClinicalSectionKeyword",
-                                                                     ["begin", "end"])
-    medication_keyword_config = EvaluationConfiguration("de.averbis.types.health.Medication", ["begin", "end"])\
-        .add_feature("drugs")\
+    clinical_section_keyword_config = EvaluationConfiguration(
+        "de.averbis.types.health.ClinicalSectionKeyword", ["begin", "end"]
+    )
+    medication_keyword_config = (
+        EvaluationConfiguration("de.averbis.types.health.Medication", ["begin", "end"])
+        .add_feature("drugs")
         .use_range_variance_partial_match(3)
+    )
     evaluation_process = comparison_process.evaluate_against(
         reference_process,
         evaluation_process_name,
-        [clinical_section_keyword_config, medication_keyword_config])
+        [clinical_section_keyword_config, medication_keyword_config],
+    )
 
     assert evaluation_process.name == evaluation_process_name
     assert evaluation_process.document_source_name == collection.name
